# under testing
	Under construction! still adding more functions!
# Examples of How To Use 


import EmailServices as es

es.disk_usage('D:/','D:/')
es.email_with_attachhment('HemantDhanwar@lucidmotors.com', 'D:\\H_Work_SPACE\\key.txt', 'HemantDhanwar@lucidmotors.com, kirankumarj@lucidmotors.com, shravankumar@lucidmotors.com', 'D:\\')

 